@@ -179,7 +179,7 @@ class DOMNode(MessagePump):
     # Names of potential computed reactives
     _computes: ClassVar[frozenset[str]]
 
-    _PSEUDO_CLASSES: ClassVar[dict[str, Callable[[object], bool]]] = {}
+    _PSEUDO_CLASSES: ClassVar[dict[str, Callable[[App[Any]], bool]]] = {}
     """Pseudo class checks."""
 
     def __init__(
@@ -228,6 +228,7 @@ class DOMNode(MessagePump):
         ) = None
         self._pruning = False
         self._query_one_cache: LRUCache[QueryOneCacheKey, DOMNode] = LRUCache(1024)
+        self._trap_focus = False
 
         super().__init__()
 
@@ -409,13 +410,22 @@ class DOMNode(MessagePump):
 
     @property
     def displayed_children(self) -> Sequence[Widget]:
-        """The displayed children (where node.display==True).
+        """The displayed children (where `node.display==True`).
 
         Returns:
             A sequence of widgets.
         """
         return self._nodes.displayed
 
+    @property
+    def displayed_and_visible_children(self) -> Sequence[Widget]:
+        """The displayed children (where `node.display==True` and `node.visible==True`).
+
+        Returns:
+            A sequence of widgets.
+        """
+        return self._nodes.displayed_and_visible
+
     @property
     def is_empty(self) -> bool:
         """Are there no displayed children?"""
@@ -466,6 +476,17 @@ class DOMNode(MessagePump):
         """The app's worker manager. Shortcut for `self.app.workers`."""
         return self.app.workers
 
+    def trap_focus(self, trap_focus: bool = True) -> None:
+        """Trap the focus.
+
+        When applied to a container, pressing tab to change focus will be limited to the container's
+        children if one of the children currently has focus.
+
+        Args:
+            trap_focus: `True` to trap focus. `False` to restore default behavior.
+        """
+        self._trap_focus = trap_focus
+
     def run_worker(
         self,
         work: WorkType[ResultType],
@@ -1714,8 +1735,6 @@ class DOMNode(MessagePump):
 
         Should be called whenever CSS classes / pseudo classes change.
         """
-        if not self.is_attached or not self.screen.is_mounted:
-            return
         try:
             self.app.update_styles(self)
         except NoActiveAppError:
